/**
 * @module jimp
 */
/// <reference types="node" />
/**
 * @class
 *
 * A `Jimp` class enables you to:class
 *
 * - Read an image into a "bit map" (a collection of pixels)
 * - Modify the bit map through methods that change the pixels
 * - Write the bit map back to an image buffer
 *
 * @example
 *
 * #### Basic
 *
 * You can use the Jimp class to make empty images.
 * This is useful for when you want to create an image that composed of other images on top of a background.
 *
 * ```ts
 * import { Jimp } from "jimp";
 *
 * const image = new Jimp({ width: 256, height: 256, color: 0xffffffff });
 * const image2 = new Jimp({ width: 100, height: 100, color: 0xff0000ff });
 *
 * image.composite(image2, 50, 50);
 * ```
 *
 * #### Node
 *
 * You can use jimp in Node.js.
 * For example you can read an image from a file and resize it and
 * then write it back to a file.
 *
 * ```ts
 * import { Jimp } from "jimp";
 * import { promises as fs } from "fs";
 *
 * const image = await Jimp.read("test/image.png");
 *
 * image.resize(256, 100);
 * image.greyscale();
 *
 * await image.write('test/output.png');
 * ```
 *
 * #### Browser
 *
 * You can use jimp in the browser by reading files from URLs
 *
 * ```ts
 * import { Jimp } from "jimp";
 *
 * const image = await Jimp.read("https://upload.wikimedia.org/wikipedia/commons/0/01/Bot-Test.jpg");
 *
 * image.resize(256, 100);
 * image.greyscale();
 *
 * const output = await image.getBuffer("test/image.png");
 *
 * const canvas = document.createElement("canvas");
 *
 * canvas.width = image.bitmap.width;
 * canvas.height = image.bitmap.height;
 *
 * const ctx = canvas.getContext("2d");
 * ctx.putImageData(image.bitmap, 0, 0);
 *
 * document.body.appendChild(canvas);
 * ```
 */
export declare const Jimp: {
    new (options?: import("@jimp/core").JimpConstructorOptions | undefined): {
        bitmap: import("@jimp/types").Bitmap;
        background: number;
        formats: import("@jimp/types").Format<any, undefined>[];
        inspect(): string;
        toString(): string;
        getBuffer<ProvidedMimeType extends string, Options extends Record<string, undefined> extends infer T ? T extends Record<string, undefined> ? T extends Record<ProvidedMimeType, infer O> ? O : never : never : never>(mime: ProvidedMimeType, options?: Options | undefined): Promise<Buffer>;
        getBase64<ProvidedMimeType_1 extends string, Options_1 extends Record<string, undefined> extends infer T_1 ? T_1 extends Record<string, undefined> ? T_1 extends Record<ProvidedMimeType_1, infer O> ? O : never : never : never>(mime: ProvidedMimeType_1, options?: Options_1 | undefined): Promise<string>;
        write<Extension extends string, Mime extends never, Options_2 extends Record<string, undefined> extends infer T_2 ? T_2 extends Record<string, undefined> ? T_2 extends Record<Mime, infer O> ? O : never : never : never>(path: `${string}.${Extension}`, options?: Options_2 | undefined): Promise<void>;
        clone<S extends unknown>(this: S): S;
        getPixelIndex(x: number, y: number, edgeHandling?: import("@jimp/types").Edge | undefined): number;
        getPixelColor(x: number, y: number): number;
        setPixelColor(hex: number, x: number, y: number): any;
        hasAlpha(): boolean;
        composite<I extends unknown>(src: I, x?: number | undefined, y?: number | undefined, options?: {
            mode?: import("@jimp/core").BlendMode | undefined;
            opacitySource?: number | undefined;
            opacityDest?: number | undefined;
        } | undefined): any;
        scan(f: (x: number, y: number, idx: number) => any): any;
        scan(x: number, y: number, w: number, h: number, cb: (x: number, y: number, idx: number) => any): any;
        scanIterator(x?: number | undefined, y?: number | undefined, w?: number | undefined, h?: number | undefined): Generator<{
            x: number;
            y: number;
            idx: number;
            image: any;
        }, void, unknown>;
    };
    read(url: string): Promise<{
        bitmap: import("@jimp/types").Bitmap;
        background: number;
        formats: import("@jimp/types").Format<any, undefined>[];
        inspect(): string;
        toString(): string;
        getBuffer<ProvidedMimeType_2 extends string, Options_3 extends Record<string, undefined> extends infer T_3 ? T_3 extends Record<string, undefined> ? T_3 extends Record<ProvidedMimeType_2, infer O> ? O : never : never : never>(mime: ProvidedMimeType_2, options?: Options_3 | undefined): Promise<Buffer>;
        getBase64<ProvidedMimeType_1_1 extends string, Options_1_1 extends Record<string, undefined> extends infer T_4 ? T_4 extends Record<string, undefined> ? T_4 extends Record<ProvidedMimeType_1_1, infer O> ? O : never : never : never>(mime: ProvidedMimeType_1_1, options?: Options_1_1 | undefined): Promise<string>;
        write<Extension_1 extends string, Mime_1 extends never, Options_2_1 extends Record<string, undefined> extends infer T_5 ? T_5 extends Record<string, undefined> ? T_5 extends Record<Mime_1, infer O> ? O : never : never : never>(path: `${string}.${Extension_1}`, options?: Options_2_1 | undefined): Promise<void>;
        clone<S_1 extends unknown>(this: S_1): S_1;
        getPixelIndex(x: number, y: number, edgeHandling?: import("@jimp/types").Edge | undefined): number;
        getPixelColor(x: number, y: number): number;
        setPixelColor(hex: number, x: number, y: number): any;
        hasAlpha(): boolean;
        composite<I_1 extends unknown>(src: I_1, x?: number | undefined, y?: number | undefined, options?: {
            mode?: import("@jimp/core").BlendMode | undefined;
            opacitySource?: number | undefined;
            opacityDest?: number | undefined;
        } | undefined): any;
        scan(f: (x: number, y: number, idx: number) => any): any;
        scan(x: number, y: number, w: number, h: number, cb: (x: number, y: number, idx: number) => any): any;
        scanIterator(x?: number | undefined, y?: number | undefined, w?: number | undefined, h?: number | undefined): Generator<{
            x: number;
            y: number;
            idx: number;
            image: any;
        }, void, unknown>;
    } & import("@jimp/core").JimpInstanceMethods<{
        bitmap: import("@jimp/types").Bitmap;
        background: number;
        formats: import("@jimp/types").Format<any, undefined>[];
        inspect(): string;
        toString(): string;
        getBuffer<ProvidedMimeType_3 extends string, Options_4 extends Record<string, undefined> extends infer T_6 ? T_6 extends Record<string, undefined> ? T_6 extends Record<ProvidedMimeType_3, infer O> ? O : never : never : never>(mime: ProvidedMimeType_3, options?: Options_4 | undefined): Promise<Buffer>;
        getBase64<ProvidedMimeType_1_2 extends string, Options_1_2 extends Record<string, undefined> extends infer T_7 ? T_7 extends Record<string, undefined> ? T_7 extends Record<ProvidedMimeType_1_2, infer O> ? O : never : never : never>(mime: ProvidedMimeType_1_2, options?: Options_1_2 | undefined): Promise<string>;
        write<Extension_2 extends string, Mime_2 extends never, Options_2_2 extends Record<string, undefined> extends infer T_8 ? T_8 extends Record<string, undefined> ? T_8 extends Record<Mime_2, infer O> ? O : never : never : never>(path: `${string}.${Extension_2}`, options?: Options_2_2 | undefined): Promise<void>;
        clone<S_2 extends unknown>(this: S_2): S_2;
        getPixelIndex(x: number, y: number, edgeHandling?: import("@jimp/types").Edge | undefined): number;
        getPixelColor(x: number, y: number): number;
        setPixelColor(hex: number, x: number, y: number): any;
        hasAlpha(): boolean;
        composite<I_2 extends unknown>(src: I_2, x?: number | undefined, y?: number | undefined, options?: {
            mode?: import("@jimp/core").BlendMode | undefined;
            opacitySource?: number | undefined;
            opacityDest?: number | undefined;
        } | undefined): any;
        scan(f: (x: number, y: number, idx: number) => any): any;
        scan(x: number, y: number, w: number, h: number, cb: (x: number, y: number, idx: number) => any): any;
        scanIterator(x?: number | undefined, y?: number | undefined, w?: number | undefined, h?: number | undefined): Generator<{
            x: number;
            y: number;
            idx: number;
            image: any;
        }, void, unknown>;
    }, {
        circle<I_3 extends import("@jimp/types").JimpClass>(image: I_3, options?: {
            x?: number | undefined;
            y?: number | undefined;
            radius?: number | undefined;
        } | undefined): I_3;
    }>>;
    fromBitmap(bitmap: import("@jimp/core").RawImageData): {
        bitmap: import("@jimp/types").Bitmap;
        background: number;
        formats: import("@jimp/types").Format<any, undefined>[];
        inspect(): string;
        toString(): string;
        getBuffer<ProvidedMimeType_4 extends string, Options_5 extends Record<string, undefined> extends infer T_9 ? T_9 extends Record<string, undefined> ? T_9 extends Record<ProvidedMimeType_4, infer O> ? O : never : never : never>(mime: ProvidedMimeType_4, options?: Options_5 | undefined): Promise<Buffer>;
        getBase64<ProvidedMimeType_1_3 extends string, Options_1_3 extends Record<string, undefined> extends infer T_10 ? T_10 extends Record<string, undefined> ? T_10 extends Record<ProvidedMimeType_1_3, infer O> ? O : never : never : never>(mime: ProvidedMimeType_1_3, options?: Options_1_3 | undefined): Promise<string>;
        write<Extension_3 extends string, Mime_3 extends never, Options_2_3 extends Record<string, undefined> extends infer T_11 ? T_11 extends Record<string, undefined> ? T_11 extends Record<Mime_3, infer O> ? O : never : never : never>(path: `${string}.${Extension_3}`, options?: Options_2_3 | undefined): Promise<void>;
        clone<S_3 extends unknown>(this: S_3): S_3;
        getPixelIndex(x: number, y: number, edgeHandling?: import("@jimp/types").Edge | undefined): number;
        getPixelColor(x: number, y: number): number;
        setPixelColor(hex: number, x: number, y: number): any;
        hasAlpha(): boolean;
        composite<I_4 extends unknown>(src: I_4, x?: number | undefined, y?: number | undefined, options?: {
            mode?: import("@jimp/core").BlendMode | undefined;
            opacitySource?: number | undefined;
            opacityDest?: number | undefined;
        } | undefined): any;
        scan(f: (x: number, y: number, idx: number) => any): any;
        scan(x: number, y: number, w: number, h: number, cb: (x: number, y: number, idx: number) => any): any;
        scanIterator(x?: number | undefined, y?: number | undefined, w?: number | undefined, h?: number | undefined): Generator<{
            x: number;
            y: number;
            idx: number;
            image: any;
        }, void, unknown>;
    } & import("@jimp/core").JimpInstanceMethods<{
        bitmap: import("@jimp/types").Bitmap;
        background: number;
        formats: import("@jimp/types").Format<any, undefined>[];
        inspect(): string;
        toString(): string;
        getBuffer<ProvidedMimeType_5 extends string, Options_6 extends Record<string, undefined> extends infer T_12 ? T_12 extends Record<string, undefined> ? T_12 extends Record<ProvidedMimeType_5, infer O> ? O : never : never : never>(mime: ProvidedMimeType_5, options?: Options_6 | undefined): Promise<Buffer>;
        getBase64<ProvidedMimeType_1_4 extends string, Options_1_4 extends Record<string, undefined> extends infer T_13 ? T_13 extends Record<string, undefined> ? T_13 extends Record<ProvidedMimeType_1_4, infer O> ? O : never : never : never>(mime: ProvidedMimeType_1_4, options?: Options_1_4 | undefined): Promise<string>;
        write<Extension_4 extends string, Mime_4 extends never, Options_2_4 extends Record<string, undefined> extends infer T_14 ? T_14 extends Record<string, undefined> ? T_14 extends Record<Mime_4, infer O> ? O : never : never : never>(path: `${string}.${Extension_4}`, options?: Options_2_4 | undefined): Promise<void>;
        clone<S_4 extends unknown>(this: S_4): S_4;
        getPixelIndex(x: number, y: number, edgeHandling?: import("@jimp/types").Edge | undefined): number;
        getPixelColor(x: number, y: number): number;
        setPixelColor(hex: number, x: number, y: number): any;
        hasAlpha(): boolean;
        composite<I_5 extends unknown>(src: I_5, x?: number | undefined, y?: number | undefined, options?: {
            mode?: import("@jimp/core").BlendMode | undefined;
            opacitySource?: number | undefined;
            opacityDest?: number | undefined;
        } | undefined): any;
        scan(f: (x: number, y: number, idx: number) => any): any;
        scan(x: number, y: number, w: number, h: number, cb: (x: number, y: number, idx: number) => any): any;
        scanIterator(x?: number | undefined, y?: number | undefined, w?: number | undefined, h?: number | undefined): Generator<{
            x: number;
            y: number;
            idx: number;
            image: any;
        }, void, unknown>;
    }, {
        circle<I_3 extends import("@jimp/types").JimpClass>(image: I_3, options?: {
            x?: number | undefined;
            y?: number | undefined;
            radius?: number | undefined;
        } | undefined): I_3;
    }>;
    fromBuffer(buffer: Buffer | ArrayBuffer): Promise<{
        bitmap: import("@jimp/types").Bitmap;
        background: number;
        formats: import("@jimp/types").Format<any, undefined>[];
        inspect(): string;
        toString(): string;
        getBuffer<ProvidedMimeType_6 extends string, Options_7 extends Record<string, undefined> extends infer T_15 ? T_15 extends Record<string, undefined> ? T_15 extends Record<ProvidedMimeType_6, infer O> ? O : never : never : never>(mime: ProvidedMimeType_6, options?: Options_7 | undefined): Promise<Buffer>;
        getBase64<ProvidedMimeType_1_5 extends string, Options_1_5 extends Record<string, undefined> extends infer T_16 ? T_16 extends Record<string, undefined> ? T_16 extends Record<ProvidedMimeType_1_5, infer O> ? O : never : never : never>(mime: ProvidedMimeType_1_5, options?: Options_1_5 | undefined): Promise<string>;
        write<Extension_5 extends string, Mime_5 extends never, Options_2_5 extends Record<string, undefined> extends infer T_17 ? T_17 extends Record<string, undefined> ? T_17 extends Record<Mime_5, infer O> ? O : never : never : never>(path: `${string}.${Extension_5}`, options?: Options_2_5 | undefined): Promise<void>;
        clone<S_5 extends unknown>(this: S_5): S_5;
        getPixelIndex(x: number, y: number, edgeHandling?: import("@jimp/types").Edge | undefined): number;
        getPixelColor(x: number, y: number): number;
        setPixelColor(hex: number, x: number, y: number): any;
        hasAlpha(): boolean;
        composite<I_6 extends unknown>(src: I_6, x?: number | undefined, y?: number | undefined, options?: {
            mode?: import("@jimp/core").BlendMode | undefined;
            opacitySource?: number | undefined;
            opacityDest?: number | undefined;
        } | undefined): any;
        scan(f: (x: number, y: number, idx: number) => any): any;
        scan(x: number, y: number, w: number, h: number, cb: (x: number, y: number, idx: number) => any): any;
        scanIterator(x?: number | undefined, y?: number | undefined, w?: number | undefined, h?: number | undefined): Generator<{
            x: number;
            y: number;
            idx: number;
            image: any;
        }, void, unknown>;
    } & import("@jimp/core").JimpInstanceMethods<{
        bitmap: import("@jimp/types").Bitmap;
        background: number;
        formats: import("@jimp/types").Format<any, undefined>[];
        inspect(): string;
        toString(): string;
        getBuffer<ProvidedMimeType_7 extends string, Options_8 extends Record<string, undefined> extends infer T_18 ? T_18 extends Record<string, undefined> ? T_18 extends Record<ProvidedMimeType_7, infer O> ? O : never : never : never>(mime: ProvidedMimeType_7, options?: Options_8 | undefined): Promise<Buffer>;
        getBase64<ProvidedMimeType_1_6 extends string, Options_1_6 extends Record<string, undefined> extends infer T_19 ? T_19 extends Record<string, undefined> ? T_19 extends Record<ProvidedMimeType_1_6, infer O> ? O : never : never : never>(mime: ProvidedMimeType_1_6, options?: Options_1_6 | undefined): Promise<string>;
        write<Extension_6 extends string, Mime_6 extends never, Options_2_6 extends Record<string, undefined> extends infer T_20 ? T_20 extends Record<string, undefined> ? T_20 extends Record<Mime_6, infer O> ? O : never : never : never>(path: `${string}.${Extension_6}`, options?: Options_2_6 | undefined): Promise<void>;
        clone<S_6 extends unknown>(this: S_6): S_6;
        getPixelIndex(x: number, y: number, edgeHandling?: import("@jimp/types").Edge | undefined): number;
        getPixelColor(x: number, y: number): number;
        setPixelColor(hex: number, x: number, y: number): any;
        hasAlpha(): boolean;
        composite<I_7 extends unknown>(src: I_7, x?: number | undefined, y?: number | undefined, options?: {
            mode?: import("@jimp/core").BlendMode | undefined;
            opacitySource?: number | undefined;
            opacityDest?: number | undefined;
        } | undefined): any;
        scan(f: (x: number, y: number, idx: number) => any): any;
        scan(x: number, y: number, w: number, h: number, cb: (x: number, y: number, idx: number) => any): any;
        scanIterator(x?: number | undefined, y?: number | undefined, w?: number | undefined, h?: number | undefined): Generator<{
            x: number;
            y: number;
            idx: number;
            image: any;
        }, void, unknown>;
    }, {
        circle<I_3 extends import("@jimp/types").JimpClass>(image: I_3, options?: {
            x?: number | undefined;
            y?: number | undefined;
            radius?: number | undefined;
        } | undefined): I_3;
    }>>;
} & (new (...args: any[]) => import("@jimp/core").JimpInstanceMethods<{
    bitmap: import("@jimp/types").Bitmap;
    background: number;
    formats: import("@jimp/types").Format<any, undefined>[];
    inspect(): string;
    toString(): string;
    getBuffer<ProvidedMimeType_8 extends string, Options_9 extends Record<string, undefined> extends infer T_21 ? T_21 extends Record<string, undefined> ? T_21 extends Record<ProvidedMimeType_8, infer O> ? O : never : never : never>(mime: ProvidedMimeType_8, options?: Options_9 | undefined): Promise<Buffer>;
    getBase64<ProvidedMimeType_1_7 extends string, Options_1_7 extends Record<string, undefined> extends infer T_22 ? T_22 extends Record<string, undefined> ? T_22 extends Record<ProvidedMimeType_1_7, infer O> ? O : never : never : never>(mime: ProvidedMimeType_1_7, options?: Options_1_7 | undefined): Promise<string>;
    write<Extension_7 extends string, Mime_7 extends never, Options_2_7 extends Record<string, undefined> extends infer T_23 ? T_23 extends Record<string, undefined> ? T_23 extends Record<Mime_7, infer O> ? O : never : never : never>(path: `${string}.${Extension_7}`, options?: Options_2_7 | undefined): Promise<void>;
    clone<S_7 extends {
        new (options?: import("@jimp/core").JimpConstructorOptions | undefined): any;
        read(url: string): Promise<any>;
        fromBitmap(bitmap: import("@jimp/core").RawImageData): any;
        fromBuffer(buffer: Buffer | ArrayBuffer): Promise<any>;
    }>(this: S_7): S_7;
    getPixelIndex(x: number, y: number, edgeHandling?: import("@jimp/types").Edge | undefined): number;
    getPixelColor(x: number, y: number): number;
    setPixelColor(hex: number, x: number, y: number): any;
    hasAlpha(): boolean;
    composite<I_8 extends unknown>(src: I_8, x?: number | undefined, y?: number | undefined, options?: {
        mode?: import("@jimp/core").BlendMode | undefined;
        opacitySource?: number | undefined;
        opacityDest?: number | undefined;
    } | undefined): any;
    scan(f: (x: number, y: number, idx: number) => any): any;
    scan(x: number, y: number, w: number, h: number, cb: (x: number, y: number, idx: number) => any): any;
    scanIterator(x?: number | undefined, y?: number | undefined, w?: number | undefined, h?: number | undefined): Generator<{
        x: number;
        y: number;
        idx: number;
        image: any;
    }, void, unknown>;
}, {
    circle<I_3 extends import("@jimp/types").JimpClass>(image: I_3, options?: {
        x?: number | undefined;
        y?: number | undefined;
        radius?: number | undefined;
    } | undefined): I_3;
}>);
//# sourceMappingURL=index.d.ts.map